# -*- coding: UTF-8 -*-
# @Time     : 2020/7/14 20:36
# @Author   : Jackie
# @File     : wechatRobot.py

import requests
from .logger import logger
from .read_config import apollo_reader


class WechatRobot:
    def __init__(self, *args, **kwargs):
        if not kwargs.get('robot_key'):
            self.robot_key = apollo_reader.get_value('weCom.robot.key')
            if not self.robot_key:
                self.robot_key = '4d52b92b-a125-48f1-8934-92c6cabf4a8d'
        else:
            self.robot_key = kwargs.get('robot_key')
        self.base_url = 'https://qyapi.weixin.qq.com/cgi-bin/webhook'
        self.message_url = self.base_url + '/send?key=%s' % self.robot_key
        self.upload_url = self.base_url + '/upload_media?key={robot_key}&type=file'.format(robot_key=self.robot_key)

    def send_message(self, message_body, msg_type='markdown'):
        msg = {
            'msgtype': msg_type,
            msg_type: message_body
        }
        response = requests.post(url=self.message_url, json=msg)
        if response.status_code == 200:
            logger.info('send weCom message success, message_body[%s]' % message_body)
        else:
            logger.error('send weCom message fail, message_body[%s], response[%s]' % (message_body, response.text))

    def get_media_id(self, file_path):
        file_name = file_path.split('/')[-1]
        files = [('file', (file_name, open(file_path, 'rb'), 'text/csv'))]
        payload = {'media': file_name, 'file': file_name, 'filename': file_name}
        headers = {'Content-Type': 'multipart/form-data'}
        response = requests.post(self.upload_url, headers=headers, data=payload, files=files)
        if response.status_code == 200:
            return response.json()['media_id']
        else:
            logger.error('WeCom get media id error, response[%s]' % response.text)
            raise RuntimeError

    def send_file(self, file_path):
        media_id = self.get_media_id(file_path)
        msg_data = {'media_id': media_id}
        self.send_message(msg_data, msg_type='file')



# -*- coding: UTF-8 -*-
# @Time     : 2/7/21 3:17 PM
# @Author   : Jackie
# @File     : utilZipfile.py

import zipfile
import os

from .logger import logger


class UtilZipfile:
    def __init__(self):
        self.util_zip = zipfile

    def zip_file(self, file_path):
        logger.info('Start zipfile[%s].' % file_path)
        filepath, file_name = os.path.split(file_path)
        zip_filename = file_name.split('.')[0]
        result_path = os.path.join(filepath, '{file_name}.zip'.format(file_name=zip_filename))
        zip_obj = self.util_zip.ZipFile(result_path, 'w', zipfile.ZIP_DEFLATED)
        zip_obj.write(file_path, arcname=file_name)
        zip_obj.close()
        logger.info('Zipfile success[%s], tar[%s]' % (file_path, result_path))
        os.remove(file_path)
        return result_path

    def zip_files(self, file_dir):
        if os.path.isdir(file_dir):
            files = os.listdir(file_dir)
            result_path = '{file_name}.zip'.format(file_name=file_dir)
            zip_obj = self.util_zip.ZipFile(result_path, 'w', zipfile.ZIP_DEFLATED)
            for file in files:
                filepath, file_name = os.path.split(file)
                zip_obj.write(filepath, arcname=file_name)
            zip_obj.close()



# -*- coding: UTF-8 -*-
# @Time     : 2021/11/4 13:56
# @Author   : Jackie
# @File     : setup.py

# coding: utf-8

from setuptools import setup, find_packages
import sys

if sys.version_info < (3, 5):
    sys.exit('Python 3.5 or greater is required.')


with open('README.md', 'rb') as fp:
    readme = fp.read()

VERSION = "1.0.3"

LICENSE = "MIT"

setup(
    name='mooyoUtils',
    version=VERSION,
    description='mooyo 常用工具包',
    long_description=readme,
    author='Jackie Chen',
    author_email='mooyo@live.cn',
    maintainer='Jackie Chen',
    maintainer_email='mooyo@live.cn',
    license=LICENSE,
    packages=find_packages(),
    platforms=["all"],
    url='http://git.ppdaicorp.com/chenqiang08/mooyoUtils.git',
    # INSTALL_REQUIRES 模块所依赖的python模块
    install_requires=['portion', 'demjson', 'python-dateutil', 'paramiko', 'redis', 'jsonpath', 'pymysql',
                      'apscheduler', 'requests', 'gnupg', 'xlrd'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)
